==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGroupByKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescription } from "./WebGroupByKeyDescription";
/**
 * @hidden
 */
var WebGroupByKeyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByKeyDescriptionMetadata, _super);
    function WebGroupByKeyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByKeyDescriptionMetadata.b = function (a) {
        if (WebGroupByKeyDescriptionMetadata.a == null) {
            WebGroupByKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByKeyDescriptionMetadata.c(WebGroupByKeyDescriptionMetadata.a);
        }
        if (a.k(WebGroupByKeyDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByKey");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("FieldName", "String");
        a.item("Value", "Unknown");
    };
    WebGroupByKeyDescriptionMetadata.d = function (a) {
        WebGroupByKeyDescriptionMetadata.b(a);
        a.ad("WebGroupByKey", function () { return new WebGroupByKeyDescription(); });
        a.ac("WebGroupByKey", WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.$t = markType(WebGroupByKeyDescriptionMetadata, 'WebGroupByKeyDescriptionMetadata');
    WebGroupByKeyDescriptionMetadata.a = null;
    return WebGroupByKeyDescriptionMetadata;
}(Base));
export { WebGroupByKeyDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGroupByKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescription } from "./WebGroupByKeyDescription";
/**
 * @hidden
 */
var WebGroupByKeyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByKeyDescriptionMetadata, _super);
    function WebGroupByKeyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByKeyDescriptionMetadata.b = function (a) {
        if (WebGroupByKeyDescriptionMetadata.a == null) {
            WebGroupByKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByKeyDescriptionMetadata.c(WebGroupByKeyDescriptionMetadata.a);
        }
        if (a.k(WebGroupByKeyDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByKey");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("FieldName", "String");
        a.item("Value", "Unknown");
    };
    WebGroupByKeyDescriptionMetadata.d = function (a) {
        WebGroupByKeyDescriptionMetadata.b(a);
        a.ae("WebGroupByKey", function () { return new WebGroupByKeyDescription(); });
        a.ad("WebGroupByKey", WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.$t = markType(WebGroupByKeyDescriptionMetadata, 'WebGroupByKeyDescriptionMetadata');
    WebGroupByKeyDescriptionMetadata.a = null;
    return WebGroupByKeyDescriptionMetadata;
}(Base));
export { WebGroupByKeyDescriptionMetadata };
